/*
 * Copyright (c) 2018. Developed by Hedgecode.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.hedgecode.chess.service.jpa;

import java.util.Date;
import java.util.List;

import javax.persistence.Query;

import org.hedgecode.chess.domain.Author;
import org.hedgecode.chess.service.AuthorService;

/**
 *
 *
 * @author Dmitry Samoshin aka gotty
 */
public class JpaAuthorService extends JpaDomainService<Author> implements AuthorService {

    @Override
    @SuppressWarnings(
            "unchecked"
    )
    public List<Author> findAll() {
        return getEntityManager().createNamedQuery(
                Author.FIND_ALL
        ).getResultList();
    }

    @Override
    @SuppressWarnings(
            "unchecked"
    )
    public Author findById(Long id) {
        Query query = getEntityManager().createNamedQuery(
                Author.FIND_BY_ID
        );
        query.setParameter(Author.ID_PARAMETER, id);
        return (Author) query.getSingleResult();
    }

    @Override
    @SuppressWarnings(
            "unchecked"
    )
    public List<Author> findByName(String name) {
        Query query = getEntityManager().createNamedQuery(
                Author.FIND_BY_NAME
        );
        query.setParameter(Author.NAME_PARAMETER, name);
        return query.getResultList();
    }

    @Override
    @SuppressWarnings(
            "unchecked"
    )
    public List<Author> findByBirthDate(Date birthdate) {
        Query query = getEntityManager().createNamedQuery(
                Author.FIND_BY_BIRTHDATE
        );
        query.setParameter(Author.BIRTHDATE_PARAMETER, birthdate);
        return query.getResultList();
    }

}
