/*
 * Copyright (c) 2018. Developed by Hedgecode.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.hedgecode.chess;

import org.hedgecode.chess.ascii.ASCIIParser;
import org.hedgecode.chess.fen.FENParser;
import org.hedgecode.chess.position.Parser;
import org.hedgecode.chess.tcd.TCDParser;
import org.hedgecode.chess.wiki.WikiParser;

/**
 * Chess Position & Game Parsers.
 *
 * @author Dmitry Samoshin aka gotty
 */
public enum Parsers {

    FEN   ( FENParser.getInstance() ),
    TCD   ( TCDParser.getInstance() ),
    ASCII ( ASCIIParser.getInstance() ),
    WIKI  ( WikiParser.getInstance() );

    private Parser parser;

    Parsers(Parser parser) {
        this.parser = parser;
    }

    public Parser parser() {
        return parser;
    }

}
