/*
 * Copyright (c) 2018. Developed by Hedgecode.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.hedgecode.chess.hedgefish;

import java.util.LinkedList;
import java.util.Queue;

import org.hedgecode.chess.uci.Transmitter;

/**
 *
 *
 * @author Dmitry Samoshin aka gotty
 */
public class HedgefishTransmitter implements Transmitter<HedgefishCommand> {

    private Queue<HedgefishCommand> queue;
    private boolean isActive;

    HedgefishTransmitter() {
        queue = new LinkedList<>();
        isActive = true;
    }

    @Override
    public boolean isActive() {
        return isActive && queue.isEmpty();
    }

    @Override
    public boolean hasCommand() {
        return !queue.isEmpty();
    }

    @Override
    public HedgefishCommand transmitCommand() {
        return queue.poll();
    }

    @Override
    public void addCommand(HedgefishCommand command) {
        if (isActive)
            queue.add(command);
    }

    @Override
    public void stop() {
        isActive = false;
    }

    @Override
    public void close() {
        queue.clear();
    }

}
