/*
 * Copyright (c) 2018-2019. Developed by Hedgecode.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.hedgecode.chess.img;

import java.io.File;
import java.io.FilenameFilter;

/**
 *
 *
 * @author Dmitry Samoshin aka gotty
 */
public class ImageFilter implements FilenameFilter {

    private static final String[] IMAGES_EXTS = ImageFormat.getAllExts();

    private String[] names;

    public ImageFilter() {
        this.names = null;
    }

    public ImageFilter(String[] names) {
        this.names = names;
    }

    @Override
    public boolean accept(File dir, String name) {
        return isImageName(name) && isImageExt(name);
    }

    private boolean isImageName(String name) {
        if (names != null) {
            name = name.substring(0, name.lastIndexOf('.'));
            for (String imageName : names) {
                if (imageName.equalsIgnoreCase(name))
                    return true;
            }
            return false;
        }
        return true;
    }

    private boolean isImageExt(String ext) {
        ext = ext.substring(ext.lastIndexOf('.') + 1);
        for (String imageExt : IMAGES_EXTS) {
            if (imageExt.equalsIgnoreCase(ext))
                return true;
        }
        return false;
    }

}
