/*
 * Copyright (c) 2018. Developed by Hedgecode.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.hedgecode.chess.ascii;

import java.util.LinkedList;
import java.util.List;

import org.apache.commons.configuration.HierarchicalConfiguration;
import org.apache.commons.configuration.XMLConfiguration;

import org.junit.Test;
import org.junit.runner.RunWith;
import org.junit.runners.JUnit4;

import org.hedgecode.chess.AbstractPositionTest;
import org.hedgecode.chess.position.Parser;
import org.hedgecode.chess.position.Position;

/**
 * Tests for {@link ASCIIParser}.
 *
 * @author Dmitry Samoshin aka gotty
 */
@RunWith(JUnit4.class)
public class ASCIIParserTest extends AbstractPositionTest implements ASCIIPositionTest {

    @Test
    public void testParse() throws Exception {
        Parser asciiParser = ASCIIParser.getInstance();
        for (HierarchicalConfiguration testConfig : getXMLConfig().configurationsAt(TESTS)) {
            setPositionName(
                    String.format(
                            MSG_ASCII_POSITION, testConfig.getString(NAME)
                    )
            );
            String ascii = testConfig.getString(ASCII_TAG);
            Position position = assignPosition(
                    testConfig.configurationAt(POSITION)
            );
            assertDiagramEquals(
                    position,
                    asciiParser.parse(ascii)
            );
        }
    }

    @Override
    public List<XMLConfiguration> getXMLPositions() throws Exception {
        List<XMLConfiguration> xmlPositions = new LinkedList<>();
        for (HierarchicalConfiguration testConfig : getXMLConfig().configurationsAt(TESTS)) {
            xmlPositions.add(
                    new XMLConfiguration(
                            testConfig.configurationAt(POSITION)
                    )
            );
        }
        return xmlPositions;
    }

}