/*
 * Copyright (c) 2018. Developed by Hedgecode.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.hedgecode.chess.uci.command;

import org.junit.Assert;
import org.junit.Test;
import org.junit.runner.RunWith;
import org.junit.runners.JUnit4;

import org.hedgecode.chess.uci.Acceptor;
import org.hedgecode.chess.uci.Engine;

/**
 * Tests for {@link AbstractCommand}.
 *
 * @author Dmitry Samoshin aka gotty
 */
@RunWith(JUnit4.class)
public class AbstractCommandTest extends Assert {

    @Test
    public void testParseMove() throws Exception {

        String[] correctMoves = {"e2e4", "e7e5", "e1g1", "e7e8q", "0000"};
        for (String correctMove : correctMoves) {
            Move move = new AbstractCommand() {
                @Override
                public void exec(Engine engine, Acceptor acceptor, String params) {
                    throw new RuntimeException("Don't supported in test class!");
                }
            }.parseMove(correctMove);

            assertNotNull(move);
        }

        String[] incorrectMoves = {"00e2", "e0e5", "e1j1", "a1a9", "e7e8k"};
        for (String incorrectMove : incorrectMoves) {
            Move move = new AbstractCommand() {
                @Override
                public void exec(Engine engine, Acceptor acceptor, String params) {
                    throw new RuntimeException("Don't supported in test class!");
                }
            }.parseMove(incorrectMove);

            assertNull(move);
        }
    }

}